Structs
Functions
encodes a set of instructions into the AnyIx format
Helper function to handle unpacking instruction data
and executing the contained instructions. At the moment
this function is not capable of handling signed CPI invocation
and will carry through signing permissions from the transaction itself